@@ -14,6 +14,9 @@
 #include <QJsonObject>
 #include <QMimeDatabase>
 #include <QMimeType>
+#include <QNetworkAccessManager>
+#include <QNetworkProxy>
+#include <QNetworkReply>
 #include <QStandardPaths>
 #include <QUuid>
 
@@ -81,21 +84,103 @@ Mms::Mms(QObject *parent)
 {
 }
 
-QByteArray Mms::encodeNotifyResponse(const QString &transactionId, const QString &status)
+void Mms::uploadMessage(const QByteArray &data)
+{
+    const QString url = SettingsManager::self()->mmsc();
+    if (url.length() < 10) {
+        qDebug() << "Invalid URL provided";
+        Q_EMIT uploadFinished(BL(""));
+        return;
+    }
+
+    //TODO default to use modem connection when connected to wifi
+    QNetworkAccessManager *manager = new QNetworkAccessManager(this);
+    QNetworkRequest request;
+    request.setUrl(QUrl(url));
+    request.setHeader(QNetworkRequest::ContentTypeHeader, SL("application/vnd.wap.mms-message"));
+    request.setHeader(QNetworkRequest::ContentLengthHeader, data.length());
+    if (!SettingsManager::self()->mmsProxy().isEmpty()) {
+        QNetworkProxy proxy;
+        proxy.setType(QNetworkProxy::HttpProxy);
+        proxy.setHostName(SettingsManager::self()->mmsProxy());
+        proxy.setPort(SettingsManager::self()->mmsPort());
+        manager->setProxy(proxy);
+    }
+
+    QNetworkReply *reply = manager->post(request, data);
+    connect(reply, &QNetworkReply::finished, this, [this, reply]() {
+        Q_EMIT uploadFinished(reply->readAll());
+        reply->deleteLater();
+    });
+
+    connect(reply, &QNetworkReply::errorOccurred, this, [this, reply]() {
+        qDebug() << "upload error:" << reply->error();
+        reply->deleteLater();
+        Q_EMIT uploadError();
+    });
+}
+
+void Mms::downloadMessage(const MmsMessage &message)
+{
+    //TODO default to use modem connection when connected to wifi
+    QNetworkAccessManager *manager = new QNetworkAccessManager(this);
+    QNetworkRequest request;
+    request.setUrl(QUrl(message.contentLocation));
+    if (!SettingsManager::self()->mmsProxy().isEmpty()) {
+        QNetworkProxy proxy;
+        proxy.setType(QNetworkProxy::HttpProxy);
+        proxy.setHostName(SettingsManager::self()->mmsProxy());
+        proxy.setPort(SettingsManager::self()->mmsPort());
+        manager->setProxy(proxy);
+    }
+
+    QNetworkReply *reply = manager->get(request);
+    connect(reply, &QNetworkReply::finished, this, [this, reply, message]() {
+        const QByteArray data = reply->readAll();
+        reply->deleteLater();
+
+        // if message exists, do not create a new download notification
+        if (!message.databaseId.isEmpty()) {
+            Q_EMIT manualDownloadFinished(message.databaseId, data.isEmpty());
+        } else if (data.isEmpty()) {
+            Q_EMIT downloadError(message);
+        }
+
+        if (!data.isEmpty()) {
+            Q_EMIT downloadFinished(data, message.contentLocation, message.expiry);
+
+            if (!message.transactionId.isEmpty()) {
+                sendDeliveryAcknowledgement(message.transactionId); // acknowledge download
+            }
+        }
+    });
+
+    connect(reply, &QNetworkReply::errorOccurred, this, [this, reply, message]() {
+        qDebug() << "download error:" << reply->error();
+        reply->deleteLater();
+        if (!message.databaseId.isEmpty()) {
+            Q_EMIT manualDownloadFinished(message.databaseId, true);
+        } else {
+            Q_EMIT downloadError(message);
+        }
+    });
+}
+
+void Mms::sendNotifyResponse(const QString &transactionId, const QString &status)
 {
     QByteArray data;
     data.append(encodeHeaderPrefix(SL("m-notifyresp-ind"), transactionId));
 
     data.append(MMS_HEADER_STATUS);
-    data.append(encodeValueFromList(status, STATUS_VALUES));
+    data.append(encodeValueFromList(status, statusValues));
 
     data.append(MMS_HEADER_REPORT_ALLOWED);
     data.append((SettingsManager::self()->shareDeliveryStatus() ? MMS_CODE_YES : MMS_CODE_NO));
 
-    return data;
+    uploadMessage(data);
 }
 
-QByteArray Mms::encodeDeliveryAcknowledgement(const QString &transactionId)
+void Mms::sendDeliveryAcknowledgement(const QString &transactionId)
 {
     QByteArray data;
     data.append(encodeHeaderPrefix(SL("m-acknowledge-ind"), transactionId));
@@ -103,32 +188,32 @@ QByteArray Mms::encodeDeliveryAcknowledgement(const QString &transactionId)
     data.append(MMS_HEADER_REPORT_ALLOWED);
     data.append((SettingsManager::self()->shareDeliveryStatus() ? MMS_CODE_YES : MMS_CODE_NO));
 
-    return data;
+    uploadMessage(data);
 }
 
-// confirms the read status of the MM to the MMS Proxy-Relay - send when marking mms messages as read
-QByteArray Mms::encodeReadReport(const QString &messageId)
+//confirms the read status of the MM to the MMS Proxy-Relay - send when marking mms messages as read
+void Mms::sendReadReport(const QString &messageId)
 {
     QByteArray data;
     data.append(encodeHeaderPrefix(SL("m-read-rec-ind"), messageId, true));
 
     data.append(MMS_HEADER_TO);
-    // data.append();
+    //data.append();
 
     data.append(MMS_HEADER_FROM);
-    // data.append();
+    //data.append();
 
     data.append(MMS_HEADER_READ_STATUS);
-    data.append(MMS_CODE_READ); // MMS_CODE_DELETE_WITHOUT_READ
+    data.append(MMS_CODE_READ); //MMS_CODE_DELETE_WITHOUT_READ
 
-    // TODO: finish this
-    return data;
+    //TODO: finish this
+    //uploadMessage(data);
 }
 
-// TODO add forwardMessage method - m-forward-req with handling of m-forward-conf - from, to, contentLocation, reportAllowed, deliveryReport, readReport
-// TODO add deleteRequest method - m-delete-req with handling of m-delete-conf - contentLocation
+ //TODO add forwardMessage method - m-forward-req with handling of m-forward-conf - from, to, contentLocation, reportAllowed, deliveryReport, readReport
+ //TODO add deleteRequest method - m-delete-req with handling of m-delete-conf - contentLocation
 
-QByteArray Mms::encodeCancelResponse(const QString &transactionId)
+void Mms::sendCancelResponse(const QString &transactionId)
 {
     QByteArray data;
     data.append(encodeHeaderPrefix(SL("m-cancel-conf"), transactionId));
@@ -136,7 +221,7 @@ QByteArray Mms::encodeCancelResponse(const QString &transactionId)
     data.append(MMS_HEADER_CANCEL_STATUS);
     data.append(MMS_CODE_CANCEL_REQUEST_SUCCESSFULLY_RECEIVED);
 
-    return data;
+    uploadMessage(data);
 }
 
 void Mms::decodeNotification(MmsMessage &message, const QByteArray &data)
@@ -155,7 +240,7 @@ void Mms::decodeNotification(MmsMessage &message, const QByteArray &data)
 
     if (data.at(pos) == 40) {
         // skip the open parenthesis
-        pos += 2;
+        pos+=2;
     }
 
     message.contentType = contentTypeValue(data, pos, message);
@@ -165,17 +250,11 @@ void Mms::decodeNotification(MmsMessage &message, const QByteArray &data)
     }
 
     pos += headerLen - pos;
-    while (decodeHeader(message, data, pos))
-        ;
-
-    // use the message transaction id if url does not contain an id
-    if (message.contentLocation.endsWith(SL("="))) {
-        message.contentLocation.append(message.transactionId);
-    }
+    while(decodeHeader(message, data, pos));
 
     // remove if successfully decoded
     if (!message.transactionId.isEmpty()) {
-        QFile file(pathTemp);
+        QFile file (pathTemp);
         file.remove();
     }
 }
@@ -183,8 +262,7 @@ void Mms::decodeNotification(MmsMessage &message, const QByteArray &data)
 void Mms::decodeConfirmation(MmsMessage &message, const QByteArray &data)
 {
     int pos = -1;
-    while (decodeHeader(message, data, pos))
-        ;
+    while(decodeHeader(message, data, pos));
 
     // Save copy for testing/debugging purposes. Delete later
     if (!message.transactionId.isEmpty()) {
@@ -202,8 +280,7 @@ void Mms::decodeMessage(MmsMessage &message, const QByteArray &data)
     saveData(data, pathTemp);
 
     int pos = -1;
-    while (decodeHeader(message, data, pos))
-        ;
+    while(decodeHeader(message, data, pos));
 
     // add from number and normalize numbers
     QStringList numbers = message.to;
@@ -211,7 +288,8 @@ void Mms::decodeMessage(MmsMessage &message, const QByteArray &data)
         numbers.append(message.from);
     }
     numbers.sort();
-    message.phoneNumberList = PhoneNumberList(numbers.join(u'~'));
+    message.phoneNumberList = PhoneNumberList(numbers.join(u';'));
+    message.from = PhoneNumber(message.from).toInternational();
 
     // remove own number if present
     const int index = message.phoneNumberList.indexOf(message.ownNumber);
@@ -219,20 +297,24 @@ void Mms::decodeMessage(MmsMessage &message, const QByteArray &data)
         message.phoneNumberList.removeAt(index);
     }
 
-    if (message.contentType == SL("application/vnd.wap.multipart.*") || message.contentType == SL("application/vnd.wap.multipart.mixed")
-        || message.contentType == SL("application/vnd.wap.multipart.form-data") || message.contentType == SL("application/vnd.wap.multipart.byteranges")
-        || message.contentType == SL("application/vnd.wap.multipart.alternative") || message.contentType == SL("application/vnd.wap.multipart.related")) {
+    if (message.contentType == SL("application/vnd.wap.multipart.*")
+        || message.contentType == SL("application/vnd.wap.multipart.mixed")
+        || message.contentType == SL("application/vnd.wap.multipart.form-data")
+        || message.contentType == SL("application/vnd.wap.multipart.byteranges")
+        || message.contentType == SL("application/vnd.wap.multipart.alternative")
+        || message.contentType == SL("application/vnd.wap.multipart.related")
+    ) {
         decodeMessageBody(message, data, pos);
     }
 
     // remove if successfully decoded or if is an outgoing message
     if (!message.messageId.isEmpty() || !message.ownNumber.isValid() || PhoneNumber(message.from) == message.ownNumber) {
-        QFile file(pathTemp);
+        QFile file (pathTemp);
         file.remove();
     }
 }
 
-void Mms::encodeMessage(MmsMessage &message, QByteArray &data, const QStringList &files, qint64 totalSize)
+void Mms::encodeMessage(MmsMessage &message, QByteArray &data, const QStringList &files, long totalSize)
 {
     auto settings = SettingsManager::self();
     int sizeLimit = settings->totalMaxAttachmentSize() * 1024;
@@ -244,34 +326,34 @@ void Mms::encodeMessage(MmsMessage &message, QByteArray &data, const QStringList
     data.append(encodeLongInteger(QDateTime::currentSecsSinceEpoch())); // optional
 
     data.append(MMS_HEADER_FROM);
-    data.append(encodeFromValue(message.from.remove(SL("-")).remove(SL(" ")) + SL("/TYPE=PLMN")));
+    data.append(encodeFromValue(message.from + SL("/TYPE=PLMN")));
     message.from.clear();
 
-    for (auto &number : message.to) {
+    for (const auto &number : message.to) {
         data.append(MMS_HEADER_TO);
-        data.append(encodeEncodedStringValue(number.remove(SL("-")).remove(SL(" ")) + SL("/TYPE=PLMN")));
+        data.append(encodeEncodedStringValue(number + SL("/TYPE=PLMN")));
     }
     message.to.clear();
 
-    // TODO add message setting for this
-    // data.append(MMS_HEADER_SENDER_VISIBILITY);
-    // data.append(MMS_CODE_YES);
+    //TODO add message setting for this
+    //data.append(MMS_HEADER_SENDER_VISIBILITY);
+    //data.append(MMS_CODE_YES);
 
-    // TODO add message setting for this
-    // data.append(MMS_HEADER_SUBJECT);
-    // data.append(encodeEncodedStringValue(SL("NoSubject")));
+    //TODO add message setting for this
+    //data.append(MMS_HEADER_SUBJECT);
+    //data.append(encodeEncodedStringValue(SL("NoSubject")));
 
-    // TODO add message setting for this
+    //TODO add message setting for this
     data.append(MMS_HEADER_MESSAGE_CLASS);
     data.append(MMS_CODE_MESSAGE_CLASS_PERSONAL);
 
-    // TODO add message setting for this
-    // data.append(MMS_HEADER_PRIORITY);
-    // data.append(MMS_CODE_PRIORITY_NORMAL);
+    //TODO add message setting for this
+    //data.append(MMS_HEADER_PRIORITY);
+    //data.append(MMS_CODE_PRIORITY_NORMAL);
 
-    // TODO add message setting for this
-    // data.append(MMS_HEADER_DELIVERY_TIME);
-    // data.append(encodeLongInteger(QDateTime::currentSecsSinceEpoch() + delaySeconds));
+    //TODO add message setting for this
+    //data.append(MMS_HEADER_DELIVERY_TIME);
+    //data.append(encodeLongInteger(QDateTime::currentSecsSinceEpoch() + delaySeconds));
 
     data.append(MMS_HEADER_READ_REPORT);
     data.append((settings->requestReadReports() ? MMS_CODE_YES : MMS_CODE_NO));
@@ -309,16 +391,6 @@ void Mms::encodeMessage(MmsMessage &message, QByteArray &data, const QStringList
         QMimeDatabase db;
         QString mimeType = db.mimeTypeForData(fileData).name();
 
-        /*
-         * WSP Content Type codes do not have numeric identifiers for the
-         * following media types. Use alternate supported media types instead.
-         */
-        if (mimeType.toLower() == SL("text/vcard")) {
-            mimeType = SL("text/x-vCard");
-        } else if (mimeType.toLower() == SL("text/calendar")) {
-            mimeType = SL("text/x-vCalendar");
-        }
-
         // resize/transcode if total size exceeds max size
         if (totalSize > sizeLimit) {
             if (mimeType.contains(SL("image")) && mimeType != SL("image/gif")) {
@@ -353,7 +425,7 @@ void Mms::encodeMessage(MmsMessage &message, QByteArray &data, const QStringList
                     imageModified.save(&buffer, "JPG");
                 }
             }
-            // TODO investigate if feasible to convert/transcode audio?
+            //TODO investigate if feasible to convert/transcode audio?
         }
 
         // shorten name and preserve extension
@@ -367,7 +439,7 @@ void Mms::encodeMessage(MmsMessage &message, QByteArray &data, const QStringList
             }
         }
 
-        data.append(encodePart(encodeValueFromList(mimeType, CONTENT_TYPES), name, fileData));
+        data.append(encodePart(encodeValueFromList(mimeType, contentTypes), name, fileData));
 
         if (parts > 1 && settings->autoCreateSmil()) {
             smil.append(SL(R"(<par dur="5000ms">)"));
@@ -385,7 +457,7 @@ void Mms::encodeMessage(MmsMessage &message, QByteArray &data, const QStringList
     // add text as one of the parts
     if (!message.text.isEmpty()) {
         const QString name = SL("text01.txt");
-        data.append(encodePart(encodeValueFromList(SL("text/plain"), CONTENT_TYPES), name, message.text.toUtf8()));
+        data.append(encodePart(encodeValueFromList(SL("text/plain"), contentTypes), name, message.text.toUtf8()));
         message.text.clear();
 
         if (parts > 1 && settings->autoCreateSmil()) {
@@ -399,8 +471,7 @@ void Mms::encodeMessage(MmsMessage &message, QByteArray &data, const QStringList
 
     if (parts > 1 && settings->autoCreateSmil()) {
         // standard layout - image and text, other files currently not included/supported
-        smil.prepend(SL(
-            R"(<smil><head><layout><root-layout/><region id="Image" fit="meet" top="0" left="0" height="80%" width="100%"/><region id="Text" top="80%" left="0" height="20%" width="100%"/></layout></head><body>)"));
+        smil.prepend(SL(R"(<smil><head><layout><root-layout/><region id="Image" fit="meet" top="0" left="0" height="80%" width="100%"/><region id="Text" top="80%" left="0" height="20%" width="100%"/></layout></head><body>)"));
 
         smil.append(SL(R"(</body></smil>)"));
 
@@ -426,66 +497,40 @@ bool Mms::decodeHeader(MmsMessage &message, const QByteArray &data, int &pos)
     }
 
     unsigned char field = data.at(++pos);
-    for (const auto &headerField : HEADER_FIELDS) {
+    for (const auto &headerField : header_fields) {
         if (headerField.id == field) {
             QVariant val;
             QStringView type = headerField.type;
-            if (type == u"")
-                val = data.at(++pos);
-            else if (type == u"unsignedInt")
-                val = unsignedInt(data, pos);
-            else if (type == u"longInteger")
-                val = longInteger(data, pos);
-            else if (type == u"shortInteger")
-                val = shortInteger(data, pos);
-            else if (type == u"integerValue")
-                val = integerValue(data, pos);
-            else if (type == u"textString")
-                val = textString(data, pos);
-            else if (type == u"encodedStringValue")
-                val = encodedStringValue(data, pos);
-            else if (type == u"fromValue")
-                val = fromValue(data, pos);
-            else if (type == u"contentTypeValue")
-                val = contentTypeValue(data, pos, message);
-            else if (type == u"messageTypeValue")
-                val = messageTypeValue(data, pos);
-            else if (type == u"dateValue")
-                val = dateValue(data, pos);
-            else if (type == u"messageClassValue")
-                val = messageClassValue(data, pos);
-            else if (type == u"mmsVersion")
-                val = mmsVersion(data, pos);
+            if (type == u"") val = data.at(++pos);
+            else if (type == u"unsignedInt") val = unsignedInt(data, pos);
+            else if (type == u"longInteger") val = longInteger(data, pos);
+            else if (type == u"shortInteger") val = shortInteger(data, pos);
+            else if (type == u"integerValue") val = integerValue(data, pos);
+            else if (type == u"textString") val = textString(data, pos);
+            else if (type == u"encodedStringValue") val = encodedStringValue(data, pos);
+            else if (type == u"fromValue") val = fromValue(data, pos);
+            else if (type == u"contentTypeValue") val = contentTypeValue(data, pos, message);
+            else if (type == u"messageTypeValue") val = messageTypeValue(data, pos);
+            else if (type == u"dateValue") val = dateValue(data, pos);
+            else if (type == u"messageClassValue") val = messageClassValue(data, pos);
+            else if (type == u"mmsVersion") val = mmsVersion(data, pos);
 
             // capture relevant values
             QStringView name = headerField.name;
-            if (name == u"messageType")
-                message.messageType = val.toString();
-            else if (name == u"transactionId")
-                message.transactionId = val.toString();
-            else if (name == u"messageId")
-                message.messageId = val.toString();
-            else if (name == u"messageSize")
-                message.messageSize = val.toInt();
-            else if (name == u"expiry")
-                message.expiry = val.toDateTime();
-            else if (name == u"date")
-                message.date = val.toDateTime();
-            else if (name == u"to")
-                message.to.append(PhoneNumber(val.toString().remove(QLatin1String("/TYPE=PLMN"))).toInternational());
-            else if (name == u"from")
-                message.from = PhoneNumber(val.toString().remove(QLatin1String("/TYPE=PLMN"))).toInternational();
-            else if (name == u"subject")
-                message.subject = val.toString();
-            else if (name == u"contentType")
-                message.contentType = val.toString();
-            else if (name == u"contentLocation")
-                message.contentLocation = val.toString();
-            else if (name == u"responseStatus")
-                message.responseStatus = val.toInt();
-            else if (name == u"responseText")
-                message.responseText = val.toString();
-            // else qDebug() << headerField.name << ":" << val.toString();
+            if (name == u"messageType") message.messageType = val.toString();
+            else if (name == u"transactionId") message.transactionId = val.toString();
+            else if (name == u"messageId") message.messageId = val.toString();
+            else if (name == u"messageSize") message.messageSize = val.toInt();
+            else if (name == u"expiry") message.expiry = val.toDateTime();
+            else if (name == u"date") message.date = val.toDateTime();
+            else if (name == u"to") message.to.append(val.toString().replace(QLatin1String("/TYPE=PLMN"), QLatin1String("")));
+            else if (name == u"from") message.from = val.toString().replace(QLatin1String("/TYPE=PLMN"), QLatin1String(""));
+            else if (name == u"subject") message.subject = val.toString();
+            else if (name == u"contentType") message.contentType = val.toString();
+            else if (name == u"contentLocation") message.contentLocation = val.toString();
+            else if (name == u"responseStatus") message.responseStatus = val.toInt();
+            else if (name == u"responseText") message.responseText = val.toString();
+            //else qDebug() << headerField.name << ":" << val.toString();
 
             return true;
         }
@@ -499,7 +544,7 @@ QByteArray Mms::encodeHeaderPrefix(const QString &type, const QString &id, bool
 {
     QByteArray data;
     data.append(MMS_HEADER_MESSAGE_TYPE);
-    data.append(encodeValueFromList(type, MESSAGE_TYPES));
+    data.append(encodeValueFromList(type, messageTypes));
 
     data.append(msgId ? MMS_HEADER_MESSAGE_ID : MMS_HEADER_TRANSACTION_ID);
     data.append(encodeTextValue(id));
@@ -524,7 +569,7 @@ bool Mms::decodeMessageBody(MmsMessage &message, const QByteArray &data, int &po
         return false;
     }
 
-    const QString folder = QString::number(hash(message.phoneNumberList.toString()));
+    const QString folder = QString::number(qHash(message.phoneNumberList.toString()));
     const QString attachmentsFolder = saveLocation(SL("attachments"), folder);
 
     QJsonArray attachments;
@@ -539,7 +584,7 @@ bool Mms::decodeMessageBody(MmsMessage &message, const QByteArray &data, int &po
         pos = temp + 1;
 
         QByteArray fileData = data.mid(pos + headerLen, dataLen);
-        pos += headerLen + dataLen - 1;
+        pos += headerLen + dataLen  - 1;
 
         if (contentType == SL("application/smil")) {
             message.smil += QString::fromUtf8(fileData);
@@ -573,13 +618,14 @@ bool Mms::decodeMessageBody(MmsMessage &message, const QByteArray &data, int &po
             name = message.partNames.length() > i ? message.partNames[i] : fileName;
 
             // json data for use in message page
-            QJsonObject object{
-                {SL("name"), name},
-                {SL("fileName"), fileName},
-                {SL("size"), dataLen},
-                {SL("mimeType"), mime.name()},
-                {SL("iconName"), mime.iconName()},
-                {SL("text"), text},
+            QJsonObject object
+            {
+                { SL("name"), name },
+                { SL("fileName"), fileName },
+                { SL("size"), dataLen },
+                { SL("mimeType"), mime.name() },
+                { SL("iconName"), mime.iconName() },
+                { SL("text"), text },
             };
 
             attachments.append(object);
@@ -635,11 +681,11 @@ bool Mms::saveData(const QByteArray &data, const QString &path)
     return true;
 }
 
-QString Mms::contentTypeValue(const QByteArray &data, int &pos, MmsMessage &message)
+QString Mms::contentTypeValue(const QByteArray &data, int & pos, MmsMessage &message)
 {
     QString type;
     if (data.at(pos + 1) & 0x80) {
-        type = lookupValString(data, pos, CONTENT_TYPES);
+        type = lookupValString(data, pos, contentTypes);
     } else if (data.at(pos + 1) == 0 || data.at(pos + 1) >= 0x20) {
         type = textString(data, pos);
     } else {
@@ -650,38 +696,29 @@ QString Mms::contentTypeValue(const QByteArray &data, int &pos, MmsMessage &mess
         if (data.at(pos + 1) == 0 || (data.at(pos + 1) >= 32 && (unsigned char)data.at(pos + 1) <= 127)) {
             type = encodedStringValue(data, pos);
         } else if ((data.at(pos + 1) & 0x80) || data.at(pos + 1) <= 30) {
-            type = lookupValString(data, pos, CONTENT_TYPES);
+            type = lookupValString(data, pos, contentTypes);
         }
 
-        while (pos < end) {
+        while(pos < end) {
             unsigned char field = data.at(++pos) & 0x7F;
-            int len = PARAM_FIELDS.size();
+            int len = param_fields.size();
             for (int i = 0; i < len; i++) {
-                if (PARAM_FIELDS[i].id == field) {
+                if (param_fields[i].id == field) {
                     QVariant val;
-                    QStringView type = PARAM_FIELDS[i].type;
-                    if (type == u"unsignedInt")
-                        val = unsignedInt(data, pos);
-                    else if (type == u"longInteger")
-                        val = longInteger(data, pos);
-                    else if (type == u"shortInteger")
-                        val = shortInteger(data, pos);
-                    else if (type == u"integerValue")
-                        val = integerValue(data, pos);
-                    else if (type == u"textString")
-                        val = textString(data, pos);
-                    else if (type == u"encodedStringValue")
-                        val = encodedStringValue(data, pos);
-                    else if (type == u"fromValue")
-                        val = fromValue(data, pos);
-                    else
-                        val = data.at(++pos);
+                    QStringView type = param_fields[i].type;
+                    if (type == u"unsignedInt") val = unsignedInt(data, pos);
+                    else if (type == u"longInteger") val = longInteger(data, pos);
+                    else if (type == u"shortInteger") val = shortInteger(data, pos);
+                    else if (type == u"integerValue") val = integerValue(data, pos);
+                    else if (type == u"textString") val = textString(data, pos);
+                    else if (type == u"encodedStringValue") val = encodedStringValue(data, pos);
+                    else if (type == u"fromValue") val = fromValue(data, pos);
+                    else val = data.at(++pos);
 
                     // store relevant values
-                    QStringView name = PARAM_FIELDS[i].name;
-                    if (name == u"name")
-                        message.partNames.append(val.toString());
-                    // else qDebug() << param_fields[i].name << ":" << val.toString();
+                    QStringView name = param_fields[i].name;
+                    if (name == u"name") message.partNames.append(val.toString());
+                    //else qDebug() << param_fields[i].name << ":" << val.toString();
 
                     i = len;
                 }
@@ -692,9 +729,9 @@ QString Mms::contentTypeValue(const QByteArray &data, int &pos, MmsMessage &mess
     return type;
 }
 
-QString Mms::messageTypeValue(const QByteArray &data, int &pos)
+QString Mms::messageTypeValue(const QByteArray &data, int & pos)
 {
-    return lookupValString(data, pos, MESSAGE_TYPES);
+    return lookupValString(data, pos, messageTypes);
 }
 
 unsigned int Mms::unsignedInt(const QByteArray &data, int &pos)
@@ -737,7 +774,7 @@ int Mms::shortInteger(const QByteArray &data, int &pos)
 
 int Mms::integerValue(const QByteArray &data, int &pos)
 {
-    if (data.at(pos + 1) < 31) {
+    if (data.at(pos + 1) < 31){
         return longInteger(data, pos);
     } else if ((unsigned char)data.at(pos + 1) > 127) {
         return shortInteger(data, pos);
@@ -817,7 +854,7 @@ QDateTime Mms::dateValue(const QByteArray &data, int &pos)
         if ((unsigned char)data.at(pos + 1) == MMS_CODE_ABSOLUTE_TOKEN) {
             pos++;
         }
-        while (pos < end) {
+        while(pos < end) {
             value = value << 8;
             value += data.at(++pos);
         }
@@ -834,7 +871,9 @@ QString Mms::messageClassValue(const QByteArray &data, int &pos)
         return QString::number(value);
     } else {
         qDebug() << "Token-text";
-        QVector<unsigned char> separators = {11, 32, 40, 41, 44, 47, 58, 59, 60, 61, 62, 63, 64, 91, 92, 93, 123, 125};
+        QVector<unsigned char> separators = {
+            11, 32, 40, 41, 44, 47, 58, 59, 60, 61, 62, 63, 64, 91, 92, 93, 123, 125
+        };
 
         QByteArray token;
         while (value > 31 && !separators.contains(value)) {
@@ -853,7 +892,7 @@ QString Mms::mmsVersion(const QByteArray &data, int &pos)
     return major + SL(".") + minor;
 }
 
-QString Mms::lookupValString(const QByteArray &data, int &pos, std::span<const QStringView> list)
+QString Mms::lookupValString(const QByteArray &data, int &pos, const QVector<QStringView> &list)
 {
     return list[shortInteger(data, pos)].toString();
 }
@@ -864,7 +903,7 @@ QByteArray Mms::encodeUnsignedInt(unsigned int value)
 
     bytes.append(value & 0x7F);
     value = value >> 7;
-    while (value > 0) {
+    while(value > 0) {
         bytes.prepend(0x80 | (value & 0x7F));
         value = value >> 7;
     }
@@ -875,7 +914,7 @@ QByteArray Mms::encodeUnsignedInt(unsigned int value)
 QByteArray Mms::encodeLongInteger(quint64 value)
 {
     QByteArray bytes;
-    while (value > 0) {
+    while(value > 0) {
         bytes.prepend(value);
         value = value >> 8;
     }
@@ -920,7 +959,7 @@ QByteArray Mms::encodeFromValue(const QString &value)
     return bytes;
 }
 
-QByteArray Mms::encodeValueFromList(const QString &value, std::span<const QStringView> list)
+QByteArray Mms::encodeValueFromList(const QString &value, const QVector<QStringView> &list)
 {
     QByteArray type;
     int index = list.size();
