@@ -7,6 +7,10 @@
 #include <KPeople/PersonsModel>
 #include <QObject>
 
+#include <unordered_map>
+
+#include "phonenumber.h"
+
 class ContactPhoneNumberMapper : public QObject
 {
     Q_OBJECT
@@ -20,19 +24,19 @@ public:
      * @param phone number
      * @return the uri belonging to the phone number
      */
-    QString uriForNumber(const QString &phoneNumber) const;
+    QString uriForNumber(const PhoneNumber &phoneNumber) const;
 
     static ContactPhoneNumberMapper &instance();
 
-signals:
+Q_SIGNALS:
     /**
      * @brief contactsChanged is emitted whenever the ContactMapper has new data,
      * because a contact was added to KPeople
      * @param list of affected numbers
      */
-    void contactsChanged(const QVector<QString> phoneNumbers);
+    void contactsChanged(const QVector<PhoneNumber> phoneNumber);
 
-private slots:
+private Q_SLOTS:
     void processRows(const int first, const int last);
 
 private:
@@ -40,6 +44,6 @@ private:
     [[nodiscard]] std::string normalizeNumber(const std::string &numberString) const;
 
     KPeople::PersonsModel *m_model;
-    std::unordered_map<std::string, QString> m_numberToUri;
+    QHash<PhoneNumber, QString> m_numberToUri;
     std::string m_country;
 };
