@@ -9,7 +9,7 @@ namespace ranges = std::ranges;
 PhoneNumberList::PhoneNumberList(const QString &phoneNumbers)
     : QVector<PhoneNumber>()
 {
-    const auto individualNumbers = phoneNumbers.split(u'~', Qt::SkipEmptyParts);
+    const auto individualNumbers = phoneNumbers.split(u';', Qt::SkipEmptyParts);
     reserve(individualNumbers.size());
 
     ranges::transform(individualNumbers, std::back_inserter(*this), [](const QString &number) {
@@ -17,14 +17,6 @@ PhoneNumberList::PhoneNumberList(const QString &phoneNumbers)
     });
 }
 
-PhoneNumberList::PhoneNumberList(const QStringList &phoneNumbers)
-    : QVector<PhoneNumber>()
-{
-    for (const auto &phone : phoneNumbers) {
-        emplace_back(phone);
-    }
-}
-
 QString PhoneNumberList::toString() const
 {
     QStringList individualNumbers;
@@ -34,14 +26,5 @@ QString PhoneNumberList::toString() const
         return number.toInternational();
     });
 
-    return individualNumbers.join(u'~');
-}
-
-QList<QString> PhoneNumberList::toStringList() const
-{
-    QList<QString> numbers;
-    for (auto it = begin(); it != end(); ++it) {
-        numbers.push_back(it->toString());
-    }
-    return numbers;
+    return individualNumbers.join(u';');
 }
