@@ -18,7 +18,9 @@ AsyncDatabase::AsyncDatabase()
 
     // Connect requests to slots
     connect(this, &AsyncDatabase::requestAddMessage, this, &AsyncDatabase::addMessage);
+    connect(this, &AsyncDatabase::requestDeleteMessage, this, &AsyncDatabase::deleteMessage);
     connect(this, &AsyncDatabase::requestUpdateMessageDeliveryState, this, &AsyncDatabase::updateMessageDeliveryState);
+    connect(this, &AsyncDatabase::requestUpdateMessageSent, this, &AsyncDatabase::updateMessageSent);
     connect(this, &AsyncDatabase::requestMarkMessageRead, this, &AsyncDatabase::markMessageRead);
     connect(this, &AsyncDatabase::requestMessagesForNumber, this, &AsyncDatabase::messagesForNumber);
     connect(this, &AsyncDatabase::requestChats, this, &AsyncDatabase::chats);
@@ -34,9 +36,14 @@ void AsyncDatabase::addMessage(const Message &message)
     m_database.addMessage(message);
 }
 
-void AsyncDatabase::messagesForNumber(const QString &phoneNumber)
+void AsyncDatabase::deleteMessage(const QString &id)
 {
-    Q_EMIT messagesFetchedForNumber(phoneNumber, m_database.messagesForNumber(phoneNumber));
+    m_database.deleteMessage(id);
+}
+
+void AsyncDatabase::messagesForNumber(const PhoneNumberList &phoneNumberList, const QString &id)
+{
+    Q_EMIT messagesFetchedForNumber(phoneNumberList, m_database.messagesForNumber(phoneNumberList, id));
 }
 
 void AsyncDatabase::updateMessageDeliveryState(const QString &id, const MessageState state)
@@ -44,6 +51,11 @@ void AsyncDatabase::updateMessageDeliveryState(const QString &id, const MessageS
     m_database.updateMessageDeliveryState(id, state);
 }
 
+void AsyncDatabase::updateMessageSent(const QString &id, const QString &messageId, const QString &contentLocation)
+{
+    m_database.updateMessageSent(id, messageId, contentLocation);
+}
+
 void AsyncDatabase::markMessageRead(const int id)
 {
     m_database.markMessageRead(id);
@@ -54,27 +66,27 @@ void AsyncDatabase::chats()
     Q_EMIT chatsFetched(m_database.chats());
 }
 
-void AsyncDatabase::unreadMessagesForNumber(const QString &phoneNumber)
+void AsyncDatabase::unreadMessagesForNumber(const PhoneNumberList &phoneNumberList)
 {
-    Q_EMIT unreadMessagesFetchedForNumber(phoneNumber, m_database.unreadMessagesForNumber(phoneNumber));
+    Q_EMIT unreadMessagesFetchedForNumber(phoneNumberList, m_database.unreadMessagesForNumber(phoneNumberList));
 }
 
-void AsyncDatabase::lastMessageForNumber(const QString &phoneNumber)
+void AsyncDatabase::lastMessageForNumber(const PhoneNumberList &phoneNumberList)
 {
-    Q_EMIT lastMessageFetchedForNumber(phoneNumber, m_database.lastMessageForNumber(phoneNumber));
+    Q_EMIT lastMessageFetchedForNumber(phoneNumberList, m_database.lastMessageForNumber(phoneNumberList));
 }
 
-void AsyncDatabase::lastContactedForNumber(const QString &phoneNumber)
+void AsyncDatabase::lastContactedForNumber(const PhoneNumberList &phoneNumberList)
 {
-    Q_EMIT lastContactedFetchedForNumber(phoneNumber, m_database.lastContactedForNumber(phoneNumber));
+    Q_EMIT lastContactedFetchedForNumber(phoneNumberList, m_database.lastContactedForNumber(phoneNumberList));
 }
 
-void AsyncDatabase::markChatAsRead(const QString &phoneNumber)
+void AsyncDatabase::markChatAsRead(const PhoneNumberList &phoneNumberList)
 {
-    m_database.markChatAsRead(phoneNumber);
+    m_database.markChatAsRead(phoneNumberList);
 }
 
-void AsyncDatabase::deleteChat(const QString &phoneNumber)
+void AsyncDatabase::deleteChat(const PhoneNumberList &phoneNumberList)
 {
-    m_database.deleteChat(phoneNumber);
+    m_database.deleteChat(phoneNumberList);
 }
