@@ -16,7 +16,6 @@
 
 class MessageModel;
 class ChannelHandler;
-class AsyncDatabase;
 
 struct ChatData {
     QString displayName;
@@ -30,14 +29,15 @@ class ChatListModel : public QAbstractListModel
     Q_OBJECT
 
 public:
+    ~ChatListModel();
+
     enum Role {
         DisplayNameRole = Qt::UserRole + 1,
-        DisplayPhoneNumberRole,
-        PhoneNumberRole,
+        PhoneNumberListRole,
         UnreadMessagesRole,
         LastContactedRole,
-        PhotoRole,
-        LastMessageRole
+        LastMessageRole,
+        IsContactRole
     };
     Q_ENUM(Role)
 
@@ -47,16 +47,18 @@ public:
     QVariant data(const QModelIndex &index, int role) const override;
     int rowCount(const QModelIndex &parent = {}) const override;
 
-    Q_INVOKABLE void startChat(const QString &phoneNumber);
-    Q_INVOKABLE void markChatAsRead(const QString &phoneNumber);
+    Q_INVOKABLE void startChat(const PhoneNumberList &phoneNumberList);
+    Q_INVOKABLE void markChatAsRead(const PhoneNumberList &phoneNumberList);
+    Q_INVOKABLE void restoreDefaults();
+    Q_INVOKABLE void saveSettings();
 
     bool ready() const;
 
-public slots:
+public Q_SLOTS:
     void fetchChats();
-    void deleteChat(const QString &phoneNumber);
+    void deleteChat(const PhoneNumberList &phoneNumberList);
 
-signals:
+Q_SIGNALS:
     void chatStarted(MessageModel* messageModel);
     void startingChatFaild(const QString &errorMessage);
 
@@ -67,4 +69,5 @@ private:
     ChannelHandler &m_handler;
     QVector<Chat> m_chats;
     ContactPhoneNumberMapper &m_mapper;
+    MessageModel *m_messageModel = nullptr;
 };
