@@ -10,6 +10,7 @@
 #include <ModemManagerQt/Manager>
 #include <ModemManagerQt/Modem>
 #include <ModemManagerQt/ModemDevice>
+#include <KContacts/PhoneNumber>
 
 #include <phonenumberlist.h>
 
@@ -51,6 +52,8 @@ public:
 
     static QString textToHtml(const QString &text);
 
+    Q_INVOKABLE QVariantList phoneNumbers(const QString &kPeopleUri);
+
     static Utils *instance();
 
     static Utils *s_instance;
